<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Monitor systemu</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>System Monitor to narzędzie do monitorowania obciążenia systemu w czasie rzeczywistym, przeglądania i kontrolowania procesów i usług działających w systemie.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Ukryj szczegóły</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Odczyt</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Zapis</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 sekund</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 dni %2 godzin %3 minut</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Użycie</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Aktualna częstotliwość</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Częstotliwość</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Producent</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Gniazd</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Procesorów logicznych</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Wirtualizacja</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1i cache</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1d cache</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2 cache</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3 cache</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Średnie obciążenie</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Deskryptorów pliku</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Procesów</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Wątków</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Nazwa hosta</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Zestaw instrukcji</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Czas działania</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 sekund</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Brak wyników wyszukiwania</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Szczegóły</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Szczegóły</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>aktywny</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>przeładowywanie</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>nieaktywny</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>błąd</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>aktywowanie</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>dezaktywacja</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>nie znaleziono</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>złe-ustawienie</translation>
    </message>
    <message>
        <source>error</source>
        <translation>błąd</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>scalone</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>zamaskowany</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>załadowany</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ręcznie</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>włączony</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>wyłączony</translation>
    </message>
    <message>
        <source>static</source>
        <translation>statyczny</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>przejściowy</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>pośredni</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>włączony-runtime</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>zamaskowany</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>wygenerowany</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>martwy</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>start-pre</translation>
    </message>
    <message>
        <source>start</source>
        <translation>start</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <source>running</source>
        <translation>pracuje</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>zakończony</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>przeładuj</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>stop</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>niepowodzenie</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>auto-restart</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>W użyciu</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Dostępne</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Współdzielone</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>W pamięci podręcznej</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Buforów</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Pamięć swap w cache</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktywne</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Nieaktywne</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Brudne</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Mapowane </translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Cały swap</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Wolny swap</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Slab</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Prędkość odczytu</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Prędkość zapisu</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Pojemność</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Sektorów odczytanych</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Odczytów/s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Sektorów odczytanych/s</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Odczytów połączonych/s</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Sektorów zapisanych</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Zapisów ukończonych</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Zapisów połączonych</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Zapisów/s</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Sektorów zapisanych/s</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Zapisów połączonych/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Wyświetl skróty</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Zakończenie tego procesu może spowodować utratę danych.
Czy na pewno chcesz kontynuować?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Zakończ proces</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Wymuszenie zakończenia tego procesu może spowodować utratę danych.
Czy na pewno chcesz kontynuować?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Wymuszenie zakończenia tej aplikacji może spowodować utratę danych.
Czy na pewno chcesz kontynuować?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Wymuś zakończenie</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Koniec</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>Adres IP:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Maska sieciowa:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Broadcast:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Prefixlen:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Zakres:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Typ połączenia</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Jakość łączenia</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Siła sygnału</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Poziom zakłóceń</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Prędkość połączenia</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>Paczki RX</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>Bajty RX</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>Błędy RX</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>Pominięte RX</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>Nadpisane RX</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>Rama RX</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>Paczki TX</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>Bajty TX</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>Błędy TX</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>Nadpisane TX</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>Dostawca TX</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>Pominięte TX</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Wiersz poleceń</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Data rozpoczęcia</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Kliknij aplikację, którą chcesz zabić</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Pamięć</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Pobieranie</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>Procesor</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Prędkość odczytu dysku</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Prędkość zapisu dysku</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Pamięć</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Nie włączone</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Wysyłanie</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Łącznie otrzymano</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Łącznie wysłano</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Wysyłanie</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Dyski</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Bardzo wysoki</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Wysoki</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normalny</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Niski</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Bardzo niski</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Niestandardowy</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Nieprawidłowy</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Błąd: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Nie udało się zmienić priorytetu procesu</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Aplikacje</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Moje procesy</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Wszystkie procesy</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>Wczytywanie</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Nie udało się wstrzymać procesu</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Nie udało się wznowić procesu</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Nie udało się zabić procesu</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nieznany błąd</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Nie udało się wysłać sygnału do przetworzenia</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Nie udało się zakończyć procesu</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 aplikacji i %2 procesów jest uruchomionych)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Brak odpowiedzi</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Zawieszony</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Zasobnik systemowy</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Zobacz lokalizację polecenia</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Właściwości</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Zakończ proces</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Wznów</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Zabij</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Zmień priorytet</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Wstrzymaj</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Priorytet niestandardowy</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Zmień</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>Procesor</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Pamięć</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Zapis dysku</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Odczyt dysku</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Wysyłanie</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Poziom priorytetu(NI)</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorytet</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Pamięć współdzielona</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Pamięć wirtualna</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Brak wsparcia</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Ochrona systemu</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Wyświetlaj ostrzeżenia, gdy użycie przekracza progi</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Nie udało się ustawić typu uruchomienia usługi</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Błąd: Nie można ustawić typu uruchomienia usługi z powodu awarii pod-procesu.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Nazwa instancji usługi</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Uruchom</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zatrzymaj</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Restartuj</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ręcznie</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Typ uruchomienia</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Załadowany</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktywny</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Pod-proces</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Stan</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Typ uruchomienia</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(Modyfikowalny)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Zakres: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Wymuś zakończenie aplikacji</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Rozszerzony</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Kompaktowy</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Widok</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Procesy</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Usługi</translation>
    </message>
</context>
</TS>
